@@ -37,14 +37,16 @@ pub enum Calcit {
   Nil,
   Bool(bool),
   Number(f64),
-  Symbol(String, String, Option<SymbolResolved>), // content, ns... so it has meta information
+  Symbol(String, String, String, Option<SymbolResolved>), // content, ns... so it has meta information
   Keyword(String),
   Str(String),
   Thunk(Box<Calcit>, Option<Box<Calcit>>),
   /// holding a path to its state
   Ref(String),
+  /// more tagged union type, more like an internal structure
   Tuple(Box<Calcit>, Box<Calcit>),
-  Recur(CalcitItems), // not data, but for recursion
+  /// not for data, but for recursion
+  Recur(CalcitItems),
   List(CalcitItems),
   Set(im::HashSet<Calcit>),
   Map(im::HashMap<Calcit, Calcit>),
@@ -220,7 +222,7 @@ impl Hash for Calcit {
         // TODO https://stackoverflow.com/q/39638363/883571
         (*n as usize).hash(_state)
       }
-      Calcit::Symbol(s, _ns, _resolved) => {
+      Calcit::Symbol(s, _ns, _at_def, _resolved) => {
         "symbol:".hash(_state);
         s.hash(_state);
         // probaly no need, also won't be used in hashing
@@ -439,6 +441,7 @@ impl PartialEq for Calcit {
 pub const CORE_NS: &str = "calcit.core";
 pub const BUILTIN_CLASSES_ENTRY: &str = "&init-builtin-classes!";
 pub const GENERATED_NS: &str = "calcit.gen";
+pub const GENERATED_DEF: &str = "gen%";
 
 impl Calcit {
   pub fn turn_string(&self) -> String {
